package com.tatacommunications.tp.jcm.dispatcher;

import javax.jms.Connection;
import javax.jms.MessageProducer;
import javax.jms.ObjectMessage;
import javax.jms.Session;
import javax.jms.TextMessage;
import javax.naming.Context;
import javax.naming.InitialContext;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
public class ConfEventProducer {

	private static final Logger LOGGER = LoggerFactory.getLogger(ConfEventProducer.class);
		
	private  javax.jms.ConnectionFactory connectionFactory;
	
	private javax.jms.Queue confEventQueue;
	
	private Session confSession;
	
	private MessageProducer confProducer;
	
	private Connection connection;
	
	private Context jndiContext;
	
	public ConfEventProducer() {
		try {

			LOGGER.info("ConfEventProducer Start");
			
			jndiContext = new InitialContext();
			
			confEventQueue = (javax.jms.Queue) jndiContext.lookup("java:/confEventQueue");
			if (confEventQueue != null) {
				LOGGER.info("confEventQueue: " + confEventQueue.toString());
			}

			connectionFactory = (javax.jms.ConnectionFactory) jndiContext.lookup("java:/EventConnectionFactory");

			if (connectionFactory != null) {
				connection = connectionFactory.createConnection();
				// create transacted session
				if (connection != null) {
					connection.start();
					confSession = connection.createSession(true, 0);
					if (confSession != null) {
						confProducer = confSession.createProducer(confEventQueue);
						confProducer.setPriority(7);
					} else {
						LOGGER.info("confSession is NULL");
					}
				} else {
					LOGGER.info("Connection is NULL");
				}
			} else {
				LOGGER.info("connectionFactory is null");
			}
		} catch (Exception e) {
			LOGGER.info("ConfEventProducer: Queue Failure {}", e);
			e.printStackTrace();
		}
	}

	public ObjectMessage createObjectMessage(ConfEvent confEvent) {
		try {
			if (confSession != null) {
				return (confSession.createObjectMessage(confEvent));
			} else {
				LOGGER.debug("confEventProducer: ConfSession is null");
				return null;
			}
		} catch (Exception e) {
			LOGGER.debug("ConfEventQueue: Message create failure {}", e);
			e.printStackTrace();
			this.close();
			return null;
		}
	}

	public void send(ObjectMessage msg) {
		try {
			confProducer.send(msg);
		} catch (Exception e) {
			LOGGER.debug("ConfEventQueue: Object Message send failure {}", e);
		}
	}
	
	public void send(TextMessage msg) {
		try {
			confProducer.send(msg);
		} catch (Exception e) {
			LOGGER.debug("ConfEventQueue: Text Message send failure {}", e);
		}
	}

	public void close() {
		try {
			if (confProducer != null) {
				confProducer.close();
			}
			if (confSession != null) {
				confSession.close();
			}
			if (connection != null) {
				connection.close();
			}
			if (jndiContext != null) {
				jndiContext.close();
			}
		} catch (Exception e) {
			LOGGER.debug(":Close Exception {}", e);
		}

	}
	
	public TextMessage createTextMessage(String string) {
		try {
			return confSession.createTextMessage(string);
		} catch (Exception e) {
			LOGGER.info("ConfEventProducer:createTextMessage Failed");
			e.printStackTrace();
			return null;
		}
	}
}
